CsvField<O, E> class abstract

Implementers

Constructors

CsvField()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toElement ToElement<O, E>
no setter

Methods

decode(String string) → E
encode(E element) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dateTime<O>(String name, ToElement<O, DateTime> toElement) DateTimeField<O>
double<O>(String name, ToElement<O, double> toElement) DoubleField<O>
int<O>(String name, ToElement<O, int> toElement) IntField<O>
string<O>(String name, ToElement<O, String> toElement) StringField<O>