DoubleField<O> class

Implemented types

Constructors

DoubleField(String name, ToElement<O, double> toElement)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toElement ToElement<O, double>
final

Methods

decode(String string) double
override
encode(double element) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited